@@ -1,6 +1,6 @@
 /***
 
-MochiKit.DateTime 1.1
+MochiKit.DateTime 1.2
 
 See <http://mochikit.com/> for documentation, downloads, license, etc.
 
@@ -21,7 +21,7 @@ if (typeof(MochiKit.DateTime) == 'undefined') {
 }
 
 MochiKit.DateTime.NAME = "MochiKit.DateTime";
-MochiKit.DateTime.VERSION = "1.1";
+MochiKit.DateTime.VERSION = "1.2";
 MochiKit.DateTime.__repr__ = function () {
     return "[" + this.NAME + " " + this.VERSION + "]";
 };
@@ -250,13 +250,16 @@ MochiKit.DateTime.__new__ = function () {
 
 MochiKit.DateTime.__new__();
 
-//MochiKit.Base._exportSymbols(this, MochiKit.DateTime);
-(function (globals, module) {
-    if ((typeof(JSAN) == 'undefined' && typeof(dojo) == 'undefined')
-        || (typeof(MochiKit.__compat__) == 'boolean' && MochiKit.__compat__)) {
-        var all = module.EXPORT_TAGS[":all"];
-        for (var i = 0; i < all.length; i++) {
-            globals[all[i]] = module[all[i]]; 
-        }
-    }   
-})(this, MochiKit.DateTime);  
+if (typeof(MochiKit.Base) != "undefined") {
+    MochiKit.Base._exportSymbols(this, MochiKit.DateTime);
+} else {
+    (function (globals, module) {
+        if ((typeof(JSAN) == 'undefined' && typeof(dojo) == 'undefined')
+            || (typeof(MochiKit.__compat__) == 'boolean' && MochiKit.__compat__)) {
+            var all = module.EXPORT_TAGS[":all"];
+            for (var i = 0; i < all.length; i++) {
+                globals[all[i]] = module[all[i]]; 
+            }
+        }   
+    })(this, MochiKit.DateTime);  
+}
