@@ -1,17 +1,16 @@
 # -*- test-case-name: nevow.test -*-
-# Copyright (c) 2004 Divmod.
+# Copyright (c) 2004-2006 Divmod.
 # See LICENSE for details.
 
-__version_info__ = (0, 7, 0)
-__version__ = '.'.join([str(i) for i in __version_info__[:3]])
-if __version_info__[3:]:
-    __version__ = '-'.join((__version__, '-'.join(__version_info__[3:])))
+from nevow._version import version
+__version_info__ = (version.major, version.minor, version.micro)
+__version__ = version.short()
 
 import sys
+from twisted.python.components import registerAdapter
 
-from nevow import compy
 from nevow import flat
-
+from nevow.util import _namedAnyWithBuiltinTranslation
 
 # Python2.2 has a stupidity where instance methods have name
 # '__builtin__.instance method' instead of '__builtin__.instancemethod'
@@ -27,7 +26,9 @@ def load(S):
         line = line.strip()
         if line and not line.startswith('#'):
             (a, o, i) = line.split()
-            compy.registerAdapter(a, clean(o), i)
+            registerAdapter(_namedAnyWithBuiltinTranslation(a),
+                            _namedAnyWithBuiltinTranslation(clean(o)),
+                            _namedAnyWithBuiltinTranslation(i))
 
 
 def loadFlatteners(S):
@@ -110,7 +111,7 @@ nevow.rend.statusFactory   nevow.context.RequestContext    nevow.inevow.IStatusM
 nevow.rend.defaultsFactory   nevow.context.RequestContext    formless.iformless.IFormDefaults
 nevow.rend.errorsFactory   nevow.context.RequestContext    formless.iformless.IFormErrors
 nevow.rend.originalFactory  nevow.context.RequestContext   nevow.inevow.IRequest
-nevow.appserver.defaultExceptionHandlerFactory   nevow.context.RequestContext    nevow.inevow.ICanHandleException
+nevow.appserver.defaultExceptionHandlerFactory   nevow.context.SiteContext    nevow.inevow.ICanHandleException
 
 nevow.rend.originalFactory  nevow.context.PageContext   nevow.inevow.IRenderer
 nevow.rend.originalFactory  nevow.context.PageContext   nevow.inevow.IRendererFactory
@@ -223,6 +224,6 @@ loadFlatteners(flatteners)
 
 
 __all__ = [
-    'accessors', 'appserver', 'blocks', 'canvas', 'compy', 'context', 'dirlist', 'entities', 'events', 'failure', 'guard', 'inevow',
-    'loaders', 'rend', 'scripts', 'stan', 'static', 'tags', 'test', 'testutil', 'url', 'util', 'vhost'
+    'accessors', 'appserver', 'blocks', 'canvas', 'context', 'dirlist', 'entities', 'events', 'failure', 'guard', 'inevow',
+    'loaders', 'rend', 'scripts', 'stan', 'static', 'tags', 'test', 'testutil', 'url', 'util', 'vhost', 'flat'
 ]
