@@ -2,29 +2,13 @@
 # Copyright (c) 2004 Divmod.
 # See LICENSE for details.
 
-r"""JavaScript Object Notation
-
-Currently only serialization is supported.  Also, serialization isn't
-completely supported.  Many strings will be incorrectly serialized.
-Floating points are not yet supported.  None serializes to null, True and
-False to true and false, tuples and lists serialize to arrays and
-dictionaries serialize to objects.
-
-unserialisation is supported via parse(str).
-
-The parser does not understand utf-8 characters at all. All unicode
-characters passed to 'dump' be encoded using the \u1000 syntax. High-ascii
-characters will be literal high unicode characters. i.e. json "\xf0" will
-become python u'\xf0' which is '\xc3\xb0' when encoded in utf-8.
-
-Brain damage: the parser understands json objects of the form
-{ "foo":"bar" }
-but the serialiser gives json objects of the form
-{ foo:"bar" }
+"""JavaScript Object Notation
 """
 
 import re, types
 
+from nevow import rend, flat, tags
+
 class ParseError(ValueError):
     pass
 
@@ -39,7 +23,38 @@ openBrace = re.compile(r'{')
 closeBrace = re.compile(r'}')
 openSquare = re.compile(r'\[')
 closeSquare = re.compile(r'\]')
-string = re.compile(r'(?<!\\)"([^"]+|\\")*(?<!\\)"')
+
+class StringTokenizer(object):
+    """
+    because r'(?<!\\)"([^"]+|\\")*(?<!\\)"'
+    """
+
+    def match(self, s):
+        if not s.startswith('"'):
+            return None
+
+        bits = []
+
+        SLASH = "\\"
+
+        bit, s = s[:1], s[1:]
+        bits = [bit]
+        while s:
+            if s.startswith(SLASH):
+                bit, s = s[:2], s[2:]
+            else:
+                bit, s = s[:1], s[1:]
+            bits.append(bit)
+            if bit == '"':
+                self.matched = ''.join(bits)
+                return self
+
+        return None
+
+    def group(self, num):
+        return self.matched
+
+string = StringTokenizer()
 identifier = re.compile(r'[A-Za-z_][A-Za-z_0-9]*')
 colon = re.compile(r':')
 comma = re.compile(r',')
@@ -58,6 +73,13 @@ class IdentifierToken(str):
 class WhitespaceToken(object):
     pass
 
+def jsonlong(s):
+    if 'e' in s:
+        m, e = map(long, s.split('e', 1))
+    else:
+        m, e = long(s), 0
+    return m * 10 ** e
+
 # list of tuples, the first element is a compiled regular expression the second
 # element returns a token and the original string.
 actions = [
@@ -74,7 +96,7 @@ actions = [
     (null, lambda s: (None, s)),
     (identifier, lambda s: (IdentifierToken(s), s)),
     (floatNumber, lambda s: (float(s), s)),
-    (longNumber, lambda s: (long(s), s)),
+    (longNumber, lambda s: (jsonlong(s), s)),
 ]
 def tokenise(s):
     tokens = []
@@ -117,10 +139,39 @@ def parseValue(tokens):
     raise ParseError, "Unexpected %r" % tokens[0]
 
 
+_stringExpr = re.compile(
+    ur'(?:\\x(?P<unicode>[a-fA-F0-9]{2})) # Match hex-escaped unicode' u'\n'
+    ur'|' u'\n'
+    ur'(?:\\u(?P<unicode2>[a-fA-F0-9]{4})) # Match hex-escaped high unicode' u'\n'
+    ur'|' u'\n'
+    ur'(?P<control>\\[fbntr\\"]) # Match escaped control characters' u'\n',
+    re.VERBOSE)
+
+_controlMap = {
+    u'\\f': u'\f',
+    u'\\b': u'\b',
+    u'\\n': u'\n',
+    u'\\t': u'\t',
+    u'\\r': u'\r',
+    u'\\"': u'"',
+    u'\\\\': u'\\',
+    }
+
+def _stringSub(m):
+    u = m.group('unicode')
+    if u is None:
+        u = m.group('unicode2')
+    if u is not None:
+        return unichr(int(u, 16))
+    c = m.group('control')
+    return _controlMap[c]
+
+
 def parseString(tokens):
     if type(tokens[0]) is not StringToken:
         raise ParseError, "Unexpected %r" % tokens[0]
-    return tokens.pop(0)[1:-1].decode('unicode-escape'), tokens
+    s = _stringExpr.sub(_stringSub, tokens.pop(0)[1:-1].decode('utf-8'))
+    return s, tokens
 
 
 def parseIdentifier(tokens):
@@ -164,6 +215,9 @@ def parseObject(tokens):
 
 
 def parse(s):
+    """
+    Return the object represented by the JSON-encoded string C{s}.
+    """
     tokens = tokenise(s)
     value, tokens = parseValue(tokens)
     if tokens:
@@ -173,6 +227,21 @@ def parse(s):
 class CycleError(Exception):
     pass
 
+_translation = dict([(o, u'\\x%02x' % (o,)) for o in range(0x20)])
+
+_translation.update({
+    ord(u'\\'): u'\\\\',
+    ord(u'"'): ur'\"',
+    ord(u'\f'): ur'\f',
+    ord(u'\b'): ur'\b',
+    ord(u'\n'): ur'\n',
+    ord(u'\t'): ur'\t',
+    ord(u'\r'): ur'\r',
+    })
+
+def stringEncode(s):
+    return s.translate(_translation).encode('utf-8')
+
 def _serialize(obj, w, seen):
     if isinstance(obj, types.BooleanType):
         if obj:
@@ -183,7 +252,7 @@ def _serialize(obj, w, seen):
         w(str(obj))
     elif isinstance(obj, unicode):
         w('"')
-        w(obj.replace('\\', '\\\\').replace('"', '\\"').encode('unicode-escape'))
+        w(stringEncode(obj))
         w('"')
     elif isinstance(obj, types.NoneType):
         w('null')
@@ -205,13 +274,26 @@ def _serialize(obj, w, seen):
             if n != len(obj) - 1:
                 w(',')
         w('}')
+    elif isinstance(obj, rend.Fragment):
+        w('"')
+        w(stringEncode(flat.flatten(tags.div(xmlns="http://www.w3.org/1999/xhtml")[obj]).decode('utf-8')))
+        w('"')
     else:
         raise TypeError("Unsupported type %r: %r" % (type(obj), obj))
 
 _undefined = object()
 def serialize(obj=_undefined, **kw):
+    """
+    JSON-encode an object.
+
+    @param obj: None, True, False, an int, long, float, unicode string,
+    list, tuple, or dictionary the JSON-encoded form of which will be
+    returned.
+    """
     if obj is _undefined:
         obj = kw
     L = []
     _serialize(obj, L.append, {})
     return ''.join(L)
+
+__all__ = ['parse', 'serialize']
