@@ -28,17 +28,9 @@ from nevow import context
 from nevow import inevow
 from nevow import tags
 from nevow import flat
-from nevow import compy
 from nevow.flat import flatsax
 
-try:
-    from twisted.python.reflect import getClass
-except ImportError:
-    def getClass(obj):
-        if hasattr(obj, '__class__'):
-            return obj.__class__
-        else:
-            return type(obj)
+from twisted.python.reflect import getClass
 
 
 class DocFactory:
@@ -73,7 +65,6 @@ class DocFactory:
         if self.precompiledDoc is None:
             self.precompiledDoc = self.precompile(ctx)
         return self.precompiledDoc
-compy.backwardsCompatImplements(DocFactory)
 
 class stan(object):
     """A stan tags document factory"""
@@ -97,7 +88,6 @@ class stan(object):
                 stan = inevow.IQ(stan).onePattern(self.pattern)
             self._cache = stan
         return self._cache
-compy.backwardsCompatImplements(stan)
 
 class htmlstr(object):
     """A document factory for HTML contained in a string"""
@@ -110,6 +100,10 @@ class htmlstr(object):
     _cache = None
 
     def __init__(self, template=None, pattern=None, beExtremelyLenient=None):
+        warnings.warn(
+            "[v0.8] htmlstr is deprecated because it's buggy. Please start using xmlfile and/or xmlstr.",
+            DeprecationWarning,
+            stacklevel=2)
         if template is not None:
             self.template = template
         if pattern is not None:
@@ -126,7 +120,6 @@ class htmlstr(object):
                 doc = inevow.IQ(doc).onePattern(self.pattern)
             self._cache = doc
         return self._cache
-compy.backwardsCompatImplements(htmlstr)
 
 class htmlfile(object):
     """A document factory for an HTML disk template"""
@@ -143,6 +136,10 @@ class htmlfile(object):
     _cache = None
 
     def __init__(self, template=None, pattern=None, templateDir=None, beExtremelyLenient=None):
+        warnings.warn(
+            "[v0.8] htmlfile is deprecated because it's buggy. Please start using xmlfile and/or xmlstr.",
+            DeprecationWarning,
+            stacklevel=2)
         if template is not None:
             self.template = template
         if pattern is not None:
@@ -164,7 +161,6 @@ class htmlfile(object):
             self._mtime = mtime
             self._cache = doc
         return self._cache
-compy.backwardsCompatImplements(htmlfile)
 
 class xmlstr(object):
 
@@ -194,7 +190,6 @@ class xmlstr(object):
                 doc = inevow.IQ(doc).onePattern(self.pattern)
             self._cache = doc
         return self._cache
-compy.backwardsCompatImplements(xmlstr)
 
 
 class xmlfile(object):
@@ -255,4 +250,5 @@ class xmlfile(object):
         self._mtime = currentModified
         self._cache[cacheKey] = currentModified, doc
         return doc
-compy.backwardsCompatImplements(xmlfile)
+
+
