@@ -18,11 +18,11 @@ Mostly, you'll use the renderers:
 """
 
 from cStringIO import StringIO
-import os.path
 from zope.interface import implements, providedBy
+import twisted.python.components as tpc
 
 from nevow.context import WovenContext, NodeNotFound, PageContext
-from nevow import compy, inevow, tags, flat, util, url
+from nevow import inevow, tags, flat, util, url
 from nevow.util import log
 
 import formless
@@ -48,7 +48,7 @@ class RenderFactory(object):
 
         callable = getattr(self, 'render_%s' % name, None)
         if callable is None:
-            callable = lambda context, data: context.tag[
+            callable = lambda *a, **kw: context.tag[
                 "The renderer named '%s' was not found in %r." % (name, self)]
 
         if args:
@@ -61,7 +61,6 @@ class RenderFactory(object):
     render_string = lambda self, context, data: string(context, data)
     render_xml = lambda self, context, data: context.tag.clear()[tags.xml(data)]
     render_data = lambda self, context, data_: data(context, data_)
-compy.backwardsCompatImplements(RenderFactory)
 
 
 class MacroFactory(object):
@@ -86,7 +85,6 @@ class MacroFactory(object):
             return lambda ctx: callable(ctx, *args)
 
         return callable
-compy.backwardsCompatImplements(MacroFactory)
 
 
 class DataNotFoundError(Exception):
@@ -121,7 +119,6 @@ class DataFactory(object):
             return callable(*args)
 
         return callable
-compy.backwardsCompatImplements(DataFactory)
 
 
 class FreeformChildMixin:
@@ -186,17 +183,21 @@ class ConfigurableMixin(object):
         which will be massaged into a MethodBinding as
         described in the ConfigurableMixin class docstring.
         """
-        binding = getattr(self, 'bind_%s' % name)
-        if callable(binding):
-            binding = binding(ctx)
+        def _get_binding(binding):
+            if callable(binding):
+                binding = util.maybeDeferred(binding, ctx)
+            return binding
 
-        if isinstance(binding, list):
-            binding = annotate.MethodBinding(
-                name, annotate.Method(arguments=[
-                    annotate.Argument(name, value, value.id)
-                    for (name, value) in binding]))
+        def _convert_list(binding):
+            if isinstance(binding, list):
+                binding = annotate.MethodBinding(
+                    name, annotate.Method(arguments=[
+                    annotate.Argument(n, v, v.id)
+                    for (n, v) in binding]))
+            return binding
 
-        return binding
+        binding = util.maybeDeferred(getattr, self, 'bind_%s' % name)
+        return binding.addCallback(_get_binding).addCallback(_convert_list)
 
     def getDefault(self, forBinding):
         """Get a default value for a given binding. If the
@@ -220,15 +221,15 @@ class ConfigurableMixin(object):
         been called. If it fails, a ValidateError exception
         will be raised.
         """
-        binding = self.getBinding(ctx, bindingName)
-        ctx.remember(binding, iformless.IBinding)
-        ctx.remember(self, iformless.IConfigurable)
-
-        rv = iformless.IInputProcessor(binding).process(ctx, self, args)
-        ctx.remember(rv, inevow.IHand)
-        ctx.remember('%r success.' % bindingName, inevow.IStatusMessage)
-        return rv
-compy.backwardsCompatImplements(ConfigurableMixin)
+        def _callback(binding):
+            ctx.remember(binding, iformless.IBinding)
+            ctx.remember(self, iformless.IConfigurable)
+            rv = iformless.IInputProcessor(binding).process(ctx, self, args)
+            ctx.remember(rv, inevow.IHand)
+            ctx.remember('%r success.' % bindingName, inevow.IStatusMessage)
+            return rv
+        return util.maybeDeferred(self.getBinding, ctx, 
+                                  bindingName).addCallback(_callback)
 
 
 class ConfigurableFactory:
@@ -257,13 +258,13 @@ class ConfigurableFactory:
         subclasses. Usage:
 
         >>> class IFoo(TypedInterface):
-        ...     def bar(self): pass
+        ...     def bar(): pass
         ...     bar = autocallable(bar)
         ...
         >>> class Foo(Page):
         ...     implements(IFoo)
         ...
-        ...     def bar(self):
+        ...     def bar():
         ...         print "bar called through the web!"
         ...
         ...     def render_forms(self, ctx, data):
@@ -291,7 +292,6 @@ class ConfigurableFactory:
         ...     docFactory = stan(render_forms)
         """
         return self.original
-compy.backwardsCompatImplements(ConfigurableFactory)
 
 _CARRYOVER = {}
 
@@ -375,7 +375,6 @@ class Fragment(DataFactory, RenderFactory, MacroFactory, ConfigurableMixin):
         # stan expressions and render_* methods and the like. But
         # because of the way objects can get intertwined, we shouldn't
         # leave the pattern changed.
-        from twisted.python.components import CannotAdapt
         old = self.docFactory.pattern
         self.docFactory.pattern = 'content'
         self.docFactory.precompiledDoc = None
@@ -385,9 +384,9 @@ class Fragment(DataFactory, RenderFactory, MacroFactory, ConfigurableMixin):
             finally:
                 self.docFactory.pattern = old
                 self.docFactory.precompiledDoc = None
-        except CannotAdapt, e:
+        except TypeError, e:
             # Avert your eyes now! I don't want to catch anything but IQ
-            # adaption exceptions here but all I get is CannotAdapt. This whole
+            # adaption exceptions here but all I get is TypeError. This whole
             # section of code is a complete hack anyway so one more won't
             # matter until it's all removed. ;-).
             if 'nevow.inevow.IQ' not in str(e):
@@ -423,7 +422,6 @@ class Fragment(DataFactory, RenderFactory, MacroFactory, ConfigurableMixin):
         ctx.remember(self, inevow.IRendererFactory)
         ctx.remember(self, inevow.IMacroFactory)
         ctx.remember(self, inevow.IData)
-compy.backwardsCompatImplements(Fragment)
 
 
 class ChildLookupMixin(FreeformChildMixin):
@@ -461,7 +459,7 @@ class ChildLookupMixin(FreeformChildMixin):
 
         w = getattr(self, 'child_%s'%segments[0], None)
         if w is not None:
-            if inevow.IResource(w, default=None) is not None:
+            if inevow.IResource(w, None) is not None:
                 return w, segments[1:]
             r = w(ctx)
             if r is not None:
@@ -645,7 +643,9 @@ class Page(Fragment, ConfigurableFactory, ChildLookupMixin):
             if hand is not None or aspects.get(iformless.IFormErrors) is not None:
                 magicCookie = '%s%s%s' % (now(),request.getClientIP(),random.random())
                 refpath = refpath.replace('_nevow_carryover_', magicCookie)
-                _CARRYOVER[magicCookie] = C = compy.Componentized(aspects)
+                _CARRYOVER[magicCookie] = C = tpc.Componentized()
+                for k, v in aspects.iteritems():
+                    C.setComponent(k, v)
 
             destination = flat.flatten(refpath, ctx)
             request.redirect(destination)
@@ -671,7 +671,6 @@ class Page(Fragment, ConfigurableFactory, ChildLookupMixin):
     def onPostFailure(self, reason, request, ctx, bindingName, redirectAfterPost):
         reason.trap(formless.ValidateError)
         return redirectAfterPost({iformless.IFormErrors: {bindingName: reason.value}})
-compy.backwardsCompatImplements(Page)
 
 
 def sequence(context, data):
@@ -788,7 +787,6 @@ class FourOhFour:
 
     def __nonzero__(self):
         return False
-compy.backwardsCompatImplements(FourOhFour)
 
 
 # Not found singleton
