@@ -1,9 +1,9 @@
 name='Nevow'
-version='0.7.0'
+from nevow import __version__ as version
 maintainer = 'Divmod, Inc.'
 maintainer_email = 'support@divmod.org'
 description = 'Web Application Construction Kit'
-url='http://divmod.org/projects/nevow'
+url='http://divmod.org/trac/wiki/DivmodNevow'
 license='MIT'
 platforms=["any"]
 classifiers=[
@@ -11,26 +11,34 @@ classifiers=[
     "Programming Language :: Python",
     "Development Status :: 4 - Beta",
     "Topic :: Internet :: WWW/HTTP :: Dynamic Content"]
-scripts=['bin/nevow-xmlgettext']
+scripts=['bin/nevow-xmlgettext', 'bin/nit']
 package_data={
         'formless': [
             'freeform-default.css'
             ],
         'nevow': [
-            'athena.js',
-            'widget.js',
-            'MochiKit.js',
-            'MochiKitLogConsole.js',
-            'liveglue.js',
-            'livetest.js',
-            'livetest-postscripts.js',
-            'livetest.css',
             'Canvas.swf',
+            '*.css',
+            '*.js',
+            ],
+        'nevow.athena_private': [
+            '*.png'
             ],
         'nevow.taglibrary': [
-            'tabbedPane.js',
-            'tabbedPane.css',
-            'progressBar.js',
-            'progressBar.css',
-            ]
+            '*.css',
+            '*.js'
+            ],
+        'nevow.livetrial': [
+            '*.css',
+            '*.js'
+            ],
+        'nevow.test': [
+            '*.js'
+            ],
+        'nevow.test.test_package.Foo': [
+            '*.js'
+            ],
+        'nevow.test.test_package.Foo.Baz': [
+            '*.js'
+            ],
         }
